<?php 

/** 

Foscam Snapshot Viewer 1.0.0 - based on EasyPhpAlbum Lite & EasyPhpThumbnail
Copyright (c) 2008-2014 JF Nutbroek <jfnutbroek@gmail.com>

Permission to use, copy, modify, and/or distribute this software for any
purpose without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

**** INSTRUCTIONS ****

Upload this file to your FTP snapshot directory on your webserver. That's all!

If you would like to organize your snapshots you can create as many directories and sub directories
as you need. It is not necessary to copy this file to the other directories, you only need it once!

**** WHAT DOES IT DO? ****

- Your snapshot directories will be indexed and organized in a menu for easy navigation
- Thumbnails (smaller versions of the snapshots) will be saved when possible (upon first viewing request)
- You can select a snapshot directory, browse through the thumbnails and click a thumbnail to view the large snapshot
- You can browse forward and backward through the snapshots or start a simple slideshow
- You can change the amount of snapshots being displayed to best fit the screen by adding rows or columns
- You can apply image processing filters to enhance the snapshot

**** Can I 'tweak' it? ****

- Yes, some simple tweaks are the settings mentioned below
- Once your snapshots directory structure is online enable the tweak '$menu_cache' for faster page loads
- For further tweaking you can edit the code

Enjoy!

*/

// Some tweaks

$menu_cache     = false;                         // Enable/disable caching of the menu (improves speed!, clear cache with 'exit' menu option)
$browsing       = true;                          // Allow forward and backward browsing
$thumbnailgrid  = '6x4';                         // The standard dimensions of the initial thumbnail grid, columns x rows
$changegrid     = true;                          // Allow the thumbnail grid to be expanded or contracted
$slideshow      = true;                          // Allow the slideshow option
$slideshowdelay = 1000;                          // Delay for slideshow in milliseconds; 1fps
$show_name      = true;                          // Show filename below photo
$thumbwidth     = 140;                           // The width (or height) of the thumbnail in px
$exitpage       = 'http://www.mywebmymail.com';  // 'Exit' will take the visitor to the page he came from, or to the URL mentioned here
$scriptname     = 'index.php';                   // The filename of the script in case you want to change it
$roundcorners   = false;                         // Round the corners of the thumbnail
$maxsnaps       = 256;                           // Maximum snapshots per album - backup will be created when exceeded

// EasyPhpAlbum Lite

session_start();

// Image manipulation request
if (isset($_REQUEST['enhance']) && isset($_REQUEST['width'])) {
	if (isset($_REQUEST['photo'])) {
		if (isset($_SESSION['album']) && isset($_SESSION['menulite'])) {
			if (key_exists($_SESSION['album'], $_SESSION['menulite'])) {
				$albumurl = $_SESSION['menulite'][$_SESSION['album']];
				$album = $albumurl[1];
				$photo = basename($_REQUEST['photo']);
				if (in_array($photo, $_SESSION['images'])) {
					$thumb = new easyphpthumbnail;
					$thumb -> Thumbsize = max(intval($_REQUEST['width']),140);
					$thumb -> Clipcorner =  array(0, 15, 0, 1, 1, 1, 1);
					$thumb -> Quality = 100;
                    $filters = '';
                    if (isset($_REQUEST['noise']) && $_REQUEST['noise'] == 1)
						$thumb -> Medianfilter = true;
					if (isset($_REQUEST['sharpen']) && $_REQUEST['sharpen'] == 1)
						$thumb -> Sharpen = true;
					if (isset($_REQUEST['negative']) && $_REQUEST['negative'] == 1)
						$thumb -> Negative = true;
                    if (isset($_REQUEST['edge']) && $_REQUEST['edge'] == 1)
                        $thumb -> Edge = true;
                    $thumb -> Copyrighttext = 'Foscam Snapshot Viewer';
					$thumb -> Createthumb($album  .  "/$photo", 'screen');
					exit;
				}
			}
		}
	} 
}

// Determine the exit URL for the exit menu option
if (!isset($_SESSION['exit'])) {
        $_SESSION['exit'] = $exitpage;
	if (isset($_SERVER['HTTP_REFERER']) && isset($_SERVER['HTTP_HOST']) && isset($_SERVER['PHP_SELF'])) {
                $thispage = strtolower('http://' . $_SERVER['HTTP_HOST'] . $_SERVER['PHP_SELF']);
                if (substr(strtolower($_SERVER['HTTP_REFERER']), 0, strlen($thispage)) != $thispage)
                        $_SESSION['exit'] = $_SERVER['HTTP_REFERER'];     
        }
}

// Verify if browser supports inline images
if (!isset($_SESSION['RFC2397'])) {
	$_SESSION['RFC2397'] = get_rfc2397();
}

// Action when 'exit' is selected from the menu
if (isset($_REQUEST['exit'])) {
        $url = $_SESSION['exit'];
        session_unset();
	session_destroy();
        header("Location: "  .  $url); 
	exit;
}

// A new album is currently being viewed -> reset the image cache
if (isset($_REQUEST['album'])) {
        $_SESSION['album'] = intval($_REQUEST['album']);
	unset($_SESSION['images']);
}

// Determine which page is being viewed
if (isset($_REQUEST['page'])) {$page = intval($_REQUEST['page']);} else {$page = 1;}

// Set width of thumbnail content section and initial display grid
if (!isset($_SESSION['columns'])) {
	$grid = explode('x', $thumbnailgrid);
	$_SESSION['columns'] = $grid[0];
}
if (!isset($_SESSION['rows'])) {
	$grid = explode('x', $thumbnailgrid);
	$_SESSION['rows'] = $grid[1];
}
if (!isset($_SESSION['width'])) {
	$_SESSION['width'] = 60 + $_SESSION['columns'] * ($thumbwidth + 30);
}

// Change the amount of columns (images next to each other)
if (isset($_REQUEST['columns']) && $changegrid) {
        $_SESSION['columns'] = max(1, intval($_REQUEST['columns']));
	if ($_SESSION['columns'] <= 4) {
		$_SESSION['width'] = 60 + $_SESSION['columns'] * ($thumbwidth + 30);
	} else {
		$_SESSION['width'] = 60 + $_SESSION['columns'] * ($thumbwidth + 30);
	}
}

// Change the amount of rows (images under each other)
if (isset($_REQUEST['rows']) && $changegrid) {
        $_SESSION['rows'] = max(1, intval($_REQUEST['rows']));
}

// A class to generate rounded thumbnails (see also the full version of EasyPhpThumbnail for custom modifications)
class easyphpthumbnail {
		
	public  $Thumbsize;			
	public  $Chmodlevel;	
	public  $Thumblocation;
	public  $Clipcorner;
	public  $Backgroundcolor;
	public  $Quality;
	public  $Medianfilter;
	public  $Sharpen;
	public  $Filter;
	public  $Divisor;
	public  $Negative;
	public  $Edge;
	public  $Offset;
	public  $Copyrighttext;
	public  $Copyrightposition;
	public  $Copyrightfontsize;
	private $image;			
	private $im;			
	private $thumb;			
	private $size;
	private $thumbx;				
	private $thumby;
	private $memsize;

	public function __construct() {
	
		$this -> Thumbsize           =  140;
		$this -> Chmodlevel          =  '0777';
		$this -> Thumblocation       =  '';
		$this -> Clipcorner          =  array(2, 15, 0, 1, 1, 1, 1);
		$this -> Filter              =  array(0,0,0,0,1,0,0,0,0);
		$this -> Divisor             =  1;
		$this -> Negative            =  false;
		$this -> Backgroundcolor     =  '#FFFFFF';
		$this -> Quality             =  '90';
		$this -> Medianfilter        =  false;		
		$this -> Sharpen             =  false;
		$this -> Edge                =  false;
		$this -> Offset              =  0;
		$this -> Copyrighttext       =  '';
		$this -> Copyrightposition   =  '0% 98%';
		$this -> Copyrightfontsize   =  2;
		$this -> memsize             =  $this -> return_bytes(ini_get('memory_limit')) * 0.55 - ($this -> Thumbsize * $this -> Thumbsize * 4);
		
	}
	
	public function __destruct() {
        
		if(is_resource($this -> im)) imagedestroy($this -> im);
		if(is_resource($this -> thumb)) imagedestroy($this -> thumb);
        
	}
	
	public function Createthumb($filename="unknown",$output="screen") {

		if (is_array($filename) && $output=="file") {
			foreach ($filename as $name) {
				$this->image=$name;
				$this->thumbmaker();
				$this->savethumb();
			}
		} else {
			$this->image=$filename;
			$this->thumbmaker();
			if ($output=="file") {$this->savethumb();} else {$this->displaythumb();}
		}
		
	}

	private function thumbmaker() {

		if ($this -> loadimage()) {
			if ($this -> Clipcorner[0] == 2) {$this -> clipcornersround();}
			if ($this->Medianfilter) {$this->medianfilter();}
			if ($this->Sharpen) {$this->sharpen();}	
			if ($this->Negative) {$this->negative();}
			if ($this->Edge) {$this->edge();}
			$this -> createemptythumbnail();
			imagecopyresampled($this -> thumb,$this -> im, 0, 0, 0, 0, $this -> thumbx,$this -> thumby,imagesx($this -> im),imagesy($this -> im));
			if ($this->Copyrighttext!='') {$this->addcopyright();}
		}
                
	}
        
	private function loadimage() {
	
		if (file_exists($this -> image)) {
			$this -> size = getimagesize($this -> image);
			if ($this -> memsize>0) {
					if (($this -> size[0]*$this -> size[1]*4)>$this -> memsize) {return false;}
			}
			switch($this -> size[2]) {
				case 1:
					if (imagetypes() & IMG_GIF) {$this -> im = imagecreatefromgif($this -> image);} 
					break;
				case 2:
					if (imagetypes() & IMG_JPG) {$this -> im = imagecreatefromjpeg($this -> image);} 
					break;
				case 3:
					if (imagetypes() & IMG_PNG) {$this -> im = imagecreatefrompng($this -> image);} 
					break;
				default:
					return false;
			}
			if (!$this -> im) {return false;} else {return true;}
		} else {
			return false;	
		}  
      
	}

	private function createemptythumbnail() {
        
		if ($this -> size[0]>$this -> size[1])
			$this -> thumb = imagecreatetruecolor($this -> Thumbsize, ceil($this -> size[1]/($this -> size[0]/$this -> Thumbsize)));
		else
			$this -> thumb = imagecreatetruecolor(ceil($this -> size[0]/($this -> size[1]/$this -> Thumbsize)), $this -> Thumbsize);
		$this -> thumbx = imagesx($this -> thumb);
		$this -> thumby = imagesy($this -> thumb);
		imagefilledrectangle($this -> thumb, 0, 0, $this -> thumbx,$this -> thumby, imagecolorallocate($this -> thumb,hexdec(substr($this -> Backgroundcolor, 1, 2)),hexdec(substr($this -> Backgroundcolor, 3, 2)),hexdec(substr($this -> Backgroundcolor, 5, 2))));
        
	}

	private function clipcornersround() {
        
		$clipsize = floor($this -> size[0]*($this -> Clipcorner[1]/100));
		$clip_degrees = 90/max($clipsize, 1);
		$points_tl = array(0, 0);
		$points_br = array($this -> size[0], $this -> size[1]);
		$points_tr = array($this -> size[0], 0);
		$points_bl = array(0, $this -> size[1]);
		$bgcolor = imagecolorallocate($this -> im,hexdec(substr($this -> Backgroundcolor, 1, 2)),hexdec(substr($this -> Backgroundcolor, 3, 2)),hexdec(substr($this -> Backgroundcolor, 5, 2)));
		for ($i = 0;$i < $clipsize;$i++) {
			$x = $clipsize * cos(deg2rad($i * $clip_degrees));
			$y = $clipsize * sin(deg2rad($i * $clip_degrees));
			array_push($points_tl, $clipsize - $x);
			array_push($points_tl, $clipsize - $y);
			array_push($points_tr, $this -> size[0] - $clipsize + $x);
			array_push($points_tr, $clipsize-$y);
			array_push($points_br, $this -> size[0] - $clipsize + $x);
			array_push($points_br, $this -> size[1] - $clipsize + $y);
			array_push($points_bl, $clipsize-$x);
			array_push($points_bl, $this -> size[1] - $clipsize + $y);
		}
		array_push($points_tl, $clipsize,0);
		array_push($points_br, $this -> size[0] - $clipsize, $this -> size[1]);
		array_push($points_tr, $this -> size[0] - $clipsize, 0);
		array_push($points_bl, $clipsize, $this -> size[1]);
		imagefilledpolygon($this -> im, $points_tl, count($points_tl) / 2, $bgcolor);
		imagefilledpolygon($this -> im, $points_bl, count($points_bl) / 2, $bgcolor);          
		imagefilledpolygon($this -> im, $points_tr, count($points_tr) / 2, $bgcolor);          
		imagefilledpolygon($this -> im, $points_br, count($points_br) / 2, $bgcolor);
		imagerectangle($this -> im, 0, 0, $this -> size[0] - 1, $this -> size[1] - 1, $bgcolor);

	}
        
	private function savethumb() {
        
		$this -> image = substr($this -> image, 0, strrpos($this -> image, '.')) . ".jpg";
		if (!file_exists($this -> Thumblocation)) {
			mkdir($this -> Thumblocation);
			chmod($this -> Thumblocation, octdec($this -> Chmodlevel));
		}
		imagejpeg($this -> thumb, $this -> Thumblocation . basename($this -> image), $this -> Quality);
		if ($this -> Chmodlevel != '') {chmod($this -> Thumblocation . basename($this -> image), octdec($this -> Chmodlevel));}
		imagedestroy($this -> im);
		imagedestroy($this -> thumb);
                
	}
	
	private function return_bytes($size_str) {
	
		switch (substr ($size_str, -1)) {
			case 'M': case 'm': return (int)$size_str * 1048576;
			case 'K': case 'k': return (int)$size_str * 1024;
			case 'G': case 'g': return (int)$size_str * 1073741824;
			default: return intval($size_str);
		}
		
	}
		
	private function medianfilter() {
		
		$this->newimage=imagecreatetruecolor($this->size[0],$this->size[1]);
		for ($y=0;$y<$this->size[1];$y++) {
			for ($x=0;$x<$this->size[0];$x++) {
				$newred=array();$newgreen=array();$newblue=array();
				$a11=$this->rgbpixel($x-1,$y-1);$a12=$this->rgbpixel($x,$y-1);$a13=$this->rgbpixel($x+1,$y-1);
				$a21=$this->rgbpixel($x-1,$y);$a22=$this->rgbpixel($x,$y);$a23=$this->rgbpixel($x+1,$y);
				$a31=$this->rgbpixel($x-1,$y+1);$a32=$this->rgbpixel($x,$y+1);$a33=$this->rgbpixel($x+1,$y+1);
				$newred[]=$a11['red'];$newgreen[]=$a11['green'];$newblue[]=$a11['blue'];
				$newred[]=$a12['red'];$newgreen[]=$a12['green'];$newblue[]=$a12['blue'];
				$newred[]=$a13['red'];$newgreen[]=$a13['green'];$newblue[]=$a13['blue'];
				$newred[]=$a21['red'];$newgreen[]=$a21['green'];$newblue[]=$a21['blue'];
				$newred[]=$a22['red'];$newgreen[]=$a22['green'];$newblue[]=$a22['blue'];
				$newred[]=$a23['red'];$newgreen[]=$a23['green'];$newblue[]=$a23['blue'];
				$newred[]=$a31['red'];$newgreen[]=$a31['green'];$newblue[]=$a31['blue'];
				$newred[]=$a32['red'];$newgreen[]=$a32['green'];$newblue[]=$a32['blue'];
				$newred[]=$a33['red'];$newgreen[]=$a33['green'];$newblue[]=$a33['blue'];
				sort($newred,SORT_NUMERIC);sort($newgreen,SORT_NUMERIC);sort($newblue,SORT_NUMERIC);
				imagesetpixel($this->newimage,$x,$y,imagecolorallocatealpha($this->newimage,$newred[4],$newgreen[4],$newblue[4],$a22['alpha']));		
			}
		}
		imagecopy($this->im,$this->newimage,0,0,0,0,$this->size[0],$this->size[1]);
		imagedestroy($this->newimage);
		
	}	
	
 	private function rgbpixel($x,$y) {
			
		if ($x<0) {$x=0;}
		if ($x>=$this->size[0]) {$x=$this->size[0]-1;}
		if ($y<0) {$y=0;}
		if ($y>=$this->size[1]) {$y=$this->size[1]-1;}		
		$pixel=ImageColorAt($this->im,$x,$y);
		return array('red' => ($pixel >> 16 & 0xFF),'green' => ($pixel >> 8 & 0xFF),'blue' => ($pixel & 0xFF),'alpha' => ($pixel >>24 & 0xFF));
		
	} 

	private function sharpen() {

		$this->Filter  = array(-1,-1,-1,-1,16,-1,-1,-1,-1);
		$this->Divisor = 8;
		$this->Offset  = 0;
		$this->filter();	
		
	}
    
	private function edge() {
        
		$this->Filter  = array(-1,-1,-1,-1,8,-1,-1,-1,-1);
		$this->Divisor = 1;
		$this->Offset  = 0;
		$this->filter();
        
	}

	private function filter() {
		
		if (function_exists('imageconvolution')) {
			imageconvolution($this->im,array(array($this->Filter[0],$this->Filter[1],$this->Filter[2]), array($this->Filter[3],$this->Filter[4],$this->Filter[5]),array($this->Filter[6],$this->Filter[7],$this->Filter[8])),$this->Divisor,$this->Offset);	
		} else {
			$newpixel=array();
			$this->newimage=imagecreatetruecolor($this->size[0],$this->size[1]);
			for ($y=0;$y<$this->size[1];$y++) {
				for ($x=0;$x<$this->size[0];$x++) {
					$newpixel[0]=0;$newpixel[1]=0;$newpixel[2]=0;
					$a11=$this->rgbpixel($x-1,$y-1);$a12=$this->rgbpixel($x,$y-1);$a13=$this->rgbpixel($x+1,$y-1);
					$a21=$this->rgbpixel($x-1,$y);$a22=$this->rgbpixel($x,$y);$a23=$this->rgbpixel($x+1,$y);
					$a31=$this->rgbpixel($x-1,$y+1);$a32=$this->rgbpixel($x,$y+1);$a33=$this->rgbpixel($x+1,$y+1);
					$newpixel[0]+=$a11['red']*$this->Filter[0]+$a12['red']*$this->Filter[1]+$a13['red']*$this->Filter[2];
					$newpixel[1]+=$a11['green']*$this->Filter[0]+$a12['green']*$this->Filter[1]+$a13['green']*$this->Filter[2];
					$newpixel[2]+=$a11['blue']*$this->Filter[0]+$a12['blue']*$this->Filter[1]+$a13['blue']*$this->Filter[2];
					$newpixel[0]+=$a21['red']*$this->Filter[3]+$a22['red']*$this->Filter[4]+$a23['red']*$this->Filter[5];
					$newpixel[1]+=$a21['green']*$this->Filter[3]+$a22['green']*$this->Filter[4]+$a23['green']*$this->Filter[5];
					$newpixel[2]+=$a21['blue']*$this->Filter[3]+$a22['blue']*$this->Filter[4]+$a23['blue']*$this->Filter[5];
					$newpixel[0]+=$a31['red']*$this->Filter[6]+$a32['red']*$this->Filter[7]+$a33['red']*$this->Filter[8];
					$newpixel[1]+=$a31['green']*$this->Filter[6]+$a32['green']*$this->Filter[7]+$a33['green']*$this->Filter[8];
					$newpixel[2]+=$a31['blue']*$this->Filter[6]+$a32['blue']*$this->Filter[7]+$a33['blue']*$this->Filter[8];
					$newpixel[0]=max(0,min(255,intval($newpixel[0]/$this->Divisor)+$this->Offset));
					$newpixel[1]=max(0,min(255,intval($newpixel[1]/$this->Divisor)+$this->Offset));
					$newpixel[2]=max(0,min(255,intval($newpixel[2]/$this->Divisor)+$this->Offset));
					imagesetpixel($this->newimage,$x,$y,imagecolorallocatealpha($this->newimage,$newpixel[0],$newpixel[1],$newpixel[2],$a11['alpha']));
				}
			}
			imagecopy($this->im,$this->newimage,0,0,0,0,$this->size[0],$this->size[1]);
			imagedestroy($this->newimage);
		}
		
	}
	
	private function negative() {
		
		if (function_exists('imagefilter')) {
			imagefilter($this->im,IMG_FILTER_NEGATE);
		} else {
			for ($y=0;$y<$this->size[1];$y++) {
				for ($x=0;$x<$this->size[0];$x++) {
					$pixel=ImageColorAt($this->im,$x,$y);
					imagesetpixel($this->im,$x,$y,imagecolorallocatealpha($this->im,255-($pixel >> 16 & 0xFF),255-($pixel >> 8 & 0xFF),255-($pixel & 0xFF),$pixel >> 24 & 0xFF));
				}
			}
		}

	}

	private function addcopyright() {
        
		$widthx=imagefontwidth($this->Copyrightfontsize)*strlen($this->Copyrighttext);
		$heighty=imagefontheight($this->Copyrightfontsize);
		$fontwidth=imagefontwidth($this->Copyrightfontsize);
		$cpos=explode(' ',str_replace('%','',$this->Copyrightposition));
		if (count($cpos)>1) {
		$cposx=floor(min(max($this->thumbx*($cpos[0]/100)-0.5*$widthx,$fontwidth),$this->thumbx-$widthx-0.5*$fontwidth));
		$cposy=floor(min(max($this->thumby*($cpos[1]/100)-0.5*$heighty,$heighty),$this->thumby-$heighty*1.5));
		} else {
		$cposx=$fontwidth;
		$cposy=$this->thumby-10;
		}
		$colors=array();
		for ($i=$cposx;$i<($cposx+$widthx);$i++) {
		$indexis=ImageColorAt($this->thumb,$i,$cposy+0.5*$heighty);
		$rgbarray=ImageColorsForIndex($this->thumb,$indexis);
		array_push($colors,$rgbarray['red'],$rgbarray['green'],$rgbarray['blue']);
		}
		if (array_sum($colors)/count($colors)>180)
			imagestring($this->thumb,$this->Copyrightfontsize,$cposx,$cposy,$this->Copyrighttext,imagecolorallocate($this->thumb,0,0,0));
		else
			imagestring($this->thumb,$this->Copyrightfontsize,$cposx,$cposy,$this->Copyrighttext,imagecolorallocate($this->thumb,255,255,255));
		
	}
	
	private function displaythumb() {
		
		header("Content-type: image/jpeg");
		imagejpeg($this->thumb,NULL,$this->Quality);
		imagedestroy($this->im);
		imagedestroy($this->thumb);
		exit;
		
	}	
	
}

// The page head containing CSS code
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"><html xmlns="http://www.w3.org/1999/xhtml" lang="en" xml:lang="en">
<head><title>Foscam Snapshot Viewer powered by EasyPhpAlbum Lite and EasyPhpThumbnail &copy; 2008-2014 www.mywebmymail.com</title>
<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
<style type="text/css">  
body {
    background-color   : #CDE;
    height             : 100%; 
    max-height         : 100%; 
    font-family        : Verdana, Helvetica, Arial, sans-serif;
    font-size          : 0.75em;
    color              : #666; 
}
<?
if (!isset($_REQUEST['slideshow'])) {
	echo "#leftmenu {\n";
    	echo "    position           : absolute;\n";
    	echo "    width              : 180px;\n";
    	echo "    height             : auto;\n";
    	echo "    overflow           : auto;\n";
    	echo "    margin             : 15px;\n";
    	echo "    background-color   : #FFF;\n";
    	echo "    padding-top        : 15px;\n";
	echo "}\n";
}
echo "#content {\n";
echo "    position           : absolute;\n";
if (!isset($_REQUEST['slideshow'])) {
	echo "    width              : " . $_SESSION['width'] . "px;\n";
	echo "    left               : 210px;";
} else {
	echo "    width              : " . ($_SESSION['width'] + 200) . "px;";	
}
?>    
    height             : auto;
    overflow           : auto; 
    margin             : 15px; 
    background-color   : #FFF; 
    padding            : 15px; 
    text-align         : center;
    z-index            : 11;    
}
#backwards {
    position           : absolute;
    left               : 15px;    
    top                : 15px;        
}
#forwards {
    position           : absolute;
    right              : 15px;    
    top                : 15px;        
}
#slideshow {
    position           : absolute;
    left               : 15px;    
    bottom             : 15px;
}
#negative {
    position           : absolute;
    right              : 15px;    
    bottom             : 15px;
}
#sharpen {
    position           : absolute;
    right              : 39px;    
    bottom             : 15px;
}
#median {
    position           : absolute;
    right              : 63px;    
    bottom             : 15px;
}
#edge {
    position           : absolute;
    right              : 87px;
    bottom             : 15px;
}
.loadingdiv {
    position           : absolute;
    top                : 15px;
    left               : 70px;
    background-color   : #CDE;
    padding            : 10px;
    border             : 2px solid;
    border-radius      : 15px;
}
.thumbnail {
    margin             : 15px;
    border             : 0;
    padding            : 0;
<?
echo "    width              : " . $thumbwidth . "px;\n";
?>
    height             : auto;
    float              : left;
    display            : inline;
    font-size          : 0.68em;
}
.topleft {
    position           : absolute;
    font-size          : 0;  
    left               : 0;    
    top                : 0; 
}
.topright {
    position           : absolute;
    font-size          : 0;     
    right              : 0;    
    top                : 0;     
}
.bottomleft {
    position           : absolute;
    font-size          : 0;  
    left               : 0;    
    bottom             : 0;       
}
.bottomright {
    position           : absolute;
    font-size          : 0;  
    right              : 0;    
    bottom             : 0;      
}
a:link,a:visited {
    color              : #666;
    text-decoration    : none;
}
a:hover {
    text-decoration    : underline;
}
</style>
<?

// Determine if the slideshow is active
if ($slideshow && isset($_REQUEST['slideshow']) && isset($_SESSION['images'])) {
	echo "</head><body onload=\"setTimeout('nextslide();',$slideshowdelay);window.status='Slideshow active - click photo to stop';\" >\n";  
	echo "<script type=\"text/javascript\">\n";
	echo "/*<![CDATA[*/\n";
	echo "var stop = false;\n";
	echo "function nextslide() {\n";
	echo "if (!stop)\n";
	$index=array_search($_REQUEST['photo'], $_SESSION['images']);
	if (key_exists($index + 1, $_SESSION['images'])) {
		echo "	location.href='$scriptname?page=$page&slideshow=1&photo=" . rawurlencode($_SESSION['images'][$index + 1]) . "';\n";
	} else {
		echo "	location.href='$scriptname?page=$page&slideshow=1&photo=" . rawurlencode($_SESSION['images'][0]) . "';\n";                
	}
	echo "}\n";
	echo " /*//]]>*/\n";
	echo "</script>\n";
} else {
	echo "</head><body>\n";
}

// Build the menu - enable menu cache to speed things up!!
$subalbums = false;
if(!isset($_SESSION['menulite']) || !$menu_cache) {
	$_SESSION['menulite'] = array();
	$home = false;
	$homedir = getcwd();
	if ($dir = opendir($homedir)) {
		while ($dirname = readdir($dir)) {
			if (substr($dirname,0,1) != '.' && is_dir($dirname) && $dirname != 'thumbs') {
				$_SESSION['menulite'][] = array(str_replace('.', '', $dirname), $dirname);
				photoalbums($homedir . '/' . $dirname . '/');
			} else if (substr($dirname,0,1) != '.' && !is_dir($dirname) && $dirname != $scriptname) {
				$extension = strtolower(substr($dirname, strrpos($dirname,'.') + 1, strlen($dirname)));
				if ($extension == 'jpg' || $extension == 'jpeg' || $extension == 'png' || $extension == 'gif')
					$home = true;
			}
		}
	}
	if ($home && count($_SESSION['menulite']) > 0) {
		array_unshift($_SESSION['menulite'], array(basename(dirname(__FILE__)), './'));
	}
}

// Sort the menu (only works when there are no sub-albums)
if (!$subalbums)
	array_multisort($_SESSION['menulite'], SORT_ASC);

// Print the menu
if (!isset($_REQUEST['slideshow'])) {
	echo "<div id=\"leftmenu\">\n";
	echo "<div class=\"topleft\">" .  topleftsprite() . "</div>\n";
	echo "<div class=\"topright\">" .  toprightsprite() . "</div>\n";
	$div1="<div style=\"padding-left : 15px;display : inline;\">";
	$div2="</div>";
	foreach($_SESSION['menulite'] as $key => $url) {
		$url[0]=trim($url[0],'.');
		if ($_SESSION['album'] == $key)
			echo "$div1<a href=\"$scriptname?album=$key\" style=\"text-decoration : underline;\">". htmlentities($url[0]) . "</a>$div2\n";
		else
			echo "$div1<a href=\"$scriptname?album=$key\">" . htmlentities($url[0]) . "</a>$div2\n";
		if (key_exists($key + 1, $_SESSION['menulite'])) {
			$nextmenuitem = $_SESSION['menulite'][$key + 1];
			if (substr($nextmenuitem[0],0,1)=='.') {
				echo "<br />\n";
				$padding_left = 15 + 15 * (substr_count($nextmenuitem[0], '.', 0, strpos($nextmenuitem[0], trim($nextmenuitem[0], '.'))) -1) . 'px';
				$div1 = "<div style=\"padding-left : $padding_left;display : inline;\">" . subcategorysprite();
				$div2 = "</div>";
			} else {
				echo "<div style=\"height : 10px;width : 100%;\">&nbsp;</div>";
				$div1 = "<div style=\"padding-left : 15px;display : inline;\">";
				$div2 = "</div>";
			}
		}
	}
	echo "<div style=\"height : 20px;width : 100%;\">&nbsp;</div><div style=\"padding-left : 15px;display : inline;\"><a href=\"$scriptname?help=1\">Help</a></div>\n";
	echo "<div style=\"height : 2px;width : 100%;\">&nbsp;</div><div style=\"padding-left : 15px;display : inline;\"><a href=\"$scriptname?exit=1\">Exit</a></div>\n";
	echo "<div style=\"height : 10px;width : 100%;\">&nbsp;</div><div style=\"font-size : 9px;text-align : center;padding-bottom : 5px;\">Foscam Snapshot Viewer<br />Powered by<br /><a href=\"http://www.mywebmymail.com/?q=content/easyphpalbum-lite\">EasyPhpAlbum Lite</a><br /><a href=\"http://www.mywebmymail.com/?q=content/easyphpthumbnail-class\">EasyPhpThumbnail</a></div>\n";
	echo "<div class=\"bottomleft\">" .  bottomleftsprite() . "</div>\n";
	echo "<div class=\"bottomright\">" .  bottomrightsprite() . "</div>\n";
	echo "</div>\n";
}

// Determine which album to show
if (count($_SESSION['menulite']) == 0) {
	$album = './';
} else {
	if (isset($_SESSION['album'])) {
		if (key_exists($_SESSION['album'], $_SESSION['menulite'])) {
			$albumurl = $_SESSION['menulite'][$_SESSION['album']];
			$album = $albumurl[1];
		}
	} else {
		$albumurl = $_SESSION['menulite'][0];
		$album = $albumurl[1];  
	}
}

// Read all image files when a new album is being viewed and store the images in the image cache
if (!isset($_SESSION['images'])) {
	$_SESSION['images'] = array();
	$newthumbs = array();
	if ($dir = opendir($album)) {
		while ($filename = readdir($dir)) {
			if (substr($dirname, 0, 1) != '.' && !is_dir($filename)) {
				$extension = strtolower(substr($filename, strrpos($filename,'.') + 1, strlen($filename)));
				if ($extension == 'jpg' || $extension == 'jpeg' || $extension == 'png' || $extension == 'gif') {
					$_SESSION['images'][] = $filename;
				}
			}
		}
	}	
}

// Sort the images - they are all time stamped 
array_multisort($_SESSION['images'], SORT_DESC);

// Check the amount of images and create a new directory if needed
$message = "No snapshot(s) found!";
if (count($_SESSION['images']) > $maxsnaps && strpos($album, 'snapbackup') === false) {
	// Rename and move the directory
	if (!file_exists($album . '/snapbackup')) {
		mkdir($album . '/snapbackup', 0777);
	}
	$stamp = "/snapbackup/" . date("Y-m-d");
	if (!file_exists($album . $stamp)) {
		mkdir($album . $stamp, 0777);
        mkdir($album . $stamp . '/thumbs/', 0777);
	}
    // Now move all images and thumbnails
    foreach($_SESSION['images'] as $key => $image) {
        $thumbimage = substr($image, 0, strrpos($image,'.') + 1)  . 'jpg';
        if (file_exists($album  .  '/thumbs/' . $thumbimage)) {
            rename($album  .  '/thumbs/' . $thumbimage, $album . $stamp . '/thumbs/' . $thumbimage);
        }
        rename($album  .  '/' . $image, $album . $stamp . '/' . $image);
    }
    // We have no more images
    $_SESSION['images'] = array();
    // We need to rebuild the menu
    unset($_SESSION['menulite']);
    // We need to display a message to the user
    $message = "Snapshots have been moved to a backup directory, please click \"snapbackup\" from the menu.";
}

// Main content
echo "<div id=\"content\">\n";
echo "<div class=\"topleft\">" .  topleftsprite() . "</div>\n";
echo "<div class=\"topright\">" .  toprightsprite() . "</div>\n";

// Display the thumbnails or the photo
$column = 0;
$thumb = new easyphpthumbnail;
$tablesize = $_SESSION['columns'] * $_SESSION['rows'];
if (isset($_REQUEST['photo'])) {$photo = basename($_REQUEST['photo']);} else {$photo = '';}
if (basename($album) == 'snapbackup') {$message = 'Please browse the backup directories, name format YYYY-MM-DD';}
if (isset($_REQUEST['help'])) {
	// Display the help page
	echo "<strong>Foscam Snapshot Viewer Help</strong><p>Use the menu on the left to browse through the directories. In the top corners you will find the following icons:</p>\n";
	echo rowminsprite() . columnminsprite() . "<br />" . rowplussprite() . columnplussprite();
	echo "<p>Use these icons to add or remove rows and columns from the thumbnail grid to match your personal preference.</p>";
	echo "<p>Click a thumbnail to view the snapshot in a larger size, and use the following icons to browse backward and forward:</p>";
	echo backsprite() . " " . forwardsprite();
	echo "<p>Return to the thumbnail grid by clicking the snapshot.</p>";
	echo "<p>When you view a snapshot you will find the following icon on the left bottom corner which will start a slideshow:</p>". slideshowsprite();
	echo "<p>And in addition the following filter options are available: Negative, Remove noise, Edge and Sharpen</p>";
	echo negativesprite() . ' ' . sharpensprite() . "<br />" . mediansprite() . ' ' . edgesprite();
	echo "<p><strong><em>Enjoy!</em></strong></p>";
	echo "<div id=\"slideshow\">Version 1.0.0</div>";
} else if ($photo == '') {
	// Display the amount of pages and the thumbnails
	if (count($_SESSION['images']) <= $page * $tablesize) {
		$page = ceil(count($_SESSION['images']) / $tablesize);
	}
	if (count($_SESSION['images']) > 0 && count($_SESSION['images']) >= ($page - 1) * $tablesize) {
		echo "<div style=\"padding-bottom : 15px;padding-left : 75px;padding-right : 75px;\">&nbsp;";
		if ($tablesize < count($_SESSION['images']) && $photo == '') {
			echo "Page: ";
			$totalpages = ceil(count($_SESSION['images']) / $tablesize);
			$mod = ceil($totalpages / 8);
			for ($i = 1; $i <= $totalpages; $i++) {
				// Don't print all pages if we have many ...
				if (fmod($i, $mod) == 0 || $i == 1 || $i == $totalpages || ($i >= $page -2 && $i <= $page +2)) {
					if ($page == $i) {
						echo " <a href=\"$scriptname?page=$i\" style=\"text-decoration : underline;\">$i</a>";
					} else {
						echo " <a href=\"$scriptname?page=$i\">$i</a>";
					} 
					if ($i != $totalpages)
						echo " - ";
				} 
			}
		}
		echo "</div>\n";
		if (count($_SESSION['images']) < $_SESSION['columns']) {
			$paddingleft = floor(($_SESSION['width'] - ($thumbwidth + 30) * count($_SESSION['images'])) / 2) . 'px';
		} else {
			$paddingleft = floor(($_SESSION['width'] - ($thumbwidth + 30) * $_SESSION['columns']) / 2) . 'px';
		}
		echo "<div style=\"padding-left : $paddingleft;padding-right : $paddingleft;height: auto;overflow: auto;\">\n";
		foreach($_SESSION['images'] as $key => $image) {
			if ($key >= ($tablesize * ($page - 1)) && $key < ($tablesize * $page)) {
				// Determine timestamp
				$timestamp = '';
				if (preg_match('/(\d{8})-(\d{6})/', $image, $result)) {
					$timestamp = substr($result[1],0,4) . "-" . substr($result[1],4,2) . '-' . substr($result[1],6,2) . ' ' . substr($result[2],0,2) . ':' . substr($result[2],2,2) . '.' . substr($result[2],4,2);
				} else  if (preg_match('/\d{14}/', $image, $result)) {
					$timestamp = substr($result[0],0,4) . "-" . substr($result[0],4,2) . '-' . substr($result[0],6,2) . ' ' . substr($result[0],8,2) . ':' . substr($result[0],10,2) . '.' . substr($result[0],12,2);				
				}
				if (file_exists($album  .  '/thumbs/' . substr($image, 0, strrpos($image,'.') + 1)  . 'jpg')) {
					echo "<div class=\"thumbnail\"><a href=\"$scriptname?page=$page&amp;photo="  .  rawurlencode($image)  .  "\"><img src=\""  .  str_replace("%2F", "/", rawurlencode($album))  .  '/thumbs/' . rawurlencode(substr($image, 0, strrpos($image,'.') + 1))  . 'jpg' .  "\" style=\"border : 0px;\" alt=\"thumb\" title=\"Click to enlarge\" /></a><br />$timestamp</div>\n";
				} else {
					// Try to create a thumbnail first
					$thumb -> Thumblocation = $album  .  '/thumbs/';
					$thumb -> Thumbsize = $thumbwidth;
					if (!$roundcorners)
						$thumb -> Clipcorner =  array(0, 15, 0, 1, 1, 1, 1);
					$thumb -> Createthumb($album  .  "/$image",'file');	
					// Verify if the thumbnail creation worked and display the thumb
					if (file_exists($album  .  '/thumbs/' . substr($image, 0, strrpos($image,'.') + 1)  . 'jpg')) {
						echo "<div class=\"thumbnail\"><a href=\"$scriptname?page=$page&amp;photo="  .  rawurlencode($image)  .  "\"><img src=\""  .  str_replace("%2F", "/", rawurlencode($album))  .  '/thumbs/' . rawurlencode(substr($image, 0, strrpos($image,'.') + 1))  . 'jpg' .  "\" style=\"border : 0px;\" alt=\"thumb\" title=\"Click to enlarge\" /></a><br />$timestamp</div>\n";
					} else {
						$size = getimagesize($album  .  "/$image");	// Getimagesize is slow but required to display non-cached thumbnails correctly
						if ($size[0] > $size[1]) {
							$width = $thumbwidth . 'px';
							$height = floor($size[1]/($size[0]/$thumbwidth)) . 'px';
						} else {
							$width = floor($size[0]/($size[1]/$thumbwidth)) . 'px';
							$height = $thumbwidth . 'px';
						}
						echo "<div class=\"thumbnail\"><a href=\"$scriptname?page=$page&amp;photo="  .  rawurlencode($image)  .  "\"><img src=\""  .  str_replace("%2F", "/", rawurlencode($album))  .  "/" . rawurlencode($image) . "\" style=\"border : 0px;width : $width; height : $height;\" alt=\"" . htmlentities($image) . "\" title=\"Click to enlarge\" /></a><br />$timestamp</div>\n";
					}
				}
				$column += 1;
				if ($column == $_SESSION['columns']) {
					$column = 0;
					echo '<br />';
				}
			}
		}
        echo "</div>";
		// Individual grid view preferences
		if ($changegrid && count($_SESSION['images']) > $_SESSION['columns']) {
			echo "<div id=\"backwards\">\n";
			echo "<a onmouseover=\"this.style.cursor='pointer';\" title=\"\" onclick=\"location.href=('$scriptname?page=$page&amp;rows="  .  max(1,$_SESSION['rows']-1)  .  "');\">";
			echo rowminsprite();
			echo "</a>\n";
			echo "<a onmouseover=\"this.style.cursor='pointer';\" title=\"\" onclick=\"location.href=('$scriptname?page=$page&amp;columns="  .  max(1,$_SESSION['columns']-1)  .  "');\">";
			echo columnminsprite();
			echo "</a>\n";
			echo "</div>\n";
			echo "<div id=\"forwards\">\n";
			echo "<a onmouseover=\"this.style.cursor='pointer';\" title=\"\" onclick=\"location.href=('$scriptname?page=$page&amp;rows="  .  max(1,$_SESSION['rows']+1)  .  "');\">\n";
			echo rowplussprite();
			echo "</a>\n";
			echo "<a onmouseover=\"this.style.cursor='pointer';\" title=\"\" onclick=\"location.href=('$scriptname?page=$page&amp;columns="  .  max(1,$_SESSION['columns']+1)  .  "');\">\n";
			echo columnplussprite();
			echo "</a>\n";		
			echo "</div>";	
		}
	} else {
		echo "<p>" . $message . "</p>\n";
	}
} else {
	// Display full sized photo
	if (in_array($photo, $_SESSION['images'])) {
		$size = getimagesize($album.'/'.$photo);	// Getimagesize is slow but required to display photos correctly within the current content width
		$enhancesize = $size[0];
		if (!isset($_REQUEST['slideshow']))
			$maxsize = $_SESSION['width'] - 60 - 30;
		else
			$maxsize = $_SESSION['width'] + 210 - 60 - 30;		
		$width = "width : $size[0]px";
		$height = "height : $size[1]px";
		if ($size[0] > $size[1]) {
			if ($size[0] > $maxsize) {
				$width = 'width : ' . $maxsize . 'px';
				$height = 'height : ' . floor($size[1] / ($size[0] / $maxsize)) . 'px';
				$enhancesize = $maxsize;
			} 
		} else  if ($size[1] > $size[0]) {
			if ($size[1] > $maxsize) {
				$width = 'width : ' . floor($size[0] / ($size[1] / $maxsize)) . 'px';
				$height = 'height : ' . $maxsize . 'px';
				$enhancesize = floor($size[0] / ($size[1] / $maxsize));
			} 		
		}
		$index = array_search($photo, $_SESSION['images']);
		$page = ceil(($index + 1) / $tablesize);
		if ($browsing && !isset($_REQUEST['slideshow']) && key_exists($index - 1, $_SESSION['images'])) {
			echo "<div id=\"backwards\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"browse backward\" onclick=\"location.href=('$scriptname?page=$page&amp;photo="  .  rawurlencode($_SESSION['images'][$index - 1])  .  "');\">\n";
			echo backsprite();
			echo "</a></div>\n";
        }
        // Current filter settings
        $filter_negative = '';
        $filter_sharpen = '';
        $filter_median = '';
        if (isset($_REQUEST['negative']) && $_REQUEST['negative'] == 1)
            $filter_negative = '&amp;negative=1';
        if (isset($_REQUEST['sharpen']) && $_REQUEST['sharpen'] == 1)
            $filter_sharpen = '&amp;sharpen=1';
        if (isset($_REQUEST['noise']) && $_REQUEST['noise'] == 1)
            $filter_median = '&amp;noise=1';
        if (isset($_REQUEST['edge']) && $_REQUEST['edge'] == 1)
            $filter_edge = '&amp;edge=1';
        // Modified or standard image
		if (isset($_REQUEST['negative']) || isset($_REQUEST['sharpen']) || isset($_REQUEST['noise']) || isset($_REQUEST['edge'])) {
            echo "<div><a href=\"$scriptname?page=$page\"><img src=\"$scriptname?page=$page&amp;enhance=1&amp;width=$enhancesize$filter_negative$filter_sharpen$filter_median$filter_edge&amp;photo="  .  rawurlencode($photo) . "\" style=\"border : 0px; $width; $height\" alt=\"" . htmlentities($photo) . "\" title=\"Click to go back\" onclick=\"stop=true;\" onload=\"hide_message();\" id=\"snapshot\" /></a></div><div id =\"loading\" class=\"loadingdiv\">Processing image ... Please wait ... This will take some time</div>\n";
		} else {
			echo "<div><a href=\"$scriptname?page=$page\"><img src=\""  .  str_replace("%2F", "/", rawurlencode($album))  .  '/'  .  rawurlencode($photo)  .  "\" style=\"border : 0px; $width; $height\" alt=\"" . htmlentities($photo) . "\" title=\"Click to go back\" onclick=\"stop=true;\" id=\"snapshot\" /></a></div>\n";
		}
		if ($show_name)
			echo "<div style=\"height : 10px;width : 100%;\">&nbsp;</div>"  . htmlentities(substr($photo, 0, strrpos($photo, '.')));		
		if ($browsing && !isset($_REQUEST['slideshow']) && key_exists($index + 1, $_SESSION['images'])) {
			echo "<div id=\"forwards\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"browse forward\" onclick=\"location.href=('$scriptname?page=$page&amp;photo="  .  rawurlencode($_SESSION['images'][$index + 1])  .  "');\">\n";
			echo forwardsprite();
			echo "</a></div>\n";			
                }
		if ($slideshow && !isset($_REQUEST['slideshow']) && count($_SESSION['images']) > 1) {
			echo "<div id=\"slideshow\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"Start Slideshow - click image to stop slideshow\" onclick=\"location.href=('$scriptname?page=$page&amp;slideshow=1&amp;photo="  .  rawurlencode($photo)  .  "');\">\n";
			echo slideshowsprite();
			echo "</a></div>\n";		
		}
		if (!isset($_REQUEST['slideshow'])) {
			if (isset($_REQUEST['negative']) && $_REQUEST['negative'] == 1)
				echo "<div id=\"negative\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"Negative image\" onclick=\"location.href=('$scriptname?page=$page&amp;negative=0$filter_sharpen$filter_median$filter_edge&amp;photo="  .  rawurlencode($photo)  .  "');\">\n";
			else 
				echo "<div id=\"negative\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"Negative image\" onclick=\"location.href=('$scriptname?page=$page&amp;negative=1$filter_sharpen$filter_median$filter_edge&amp;photo="  .  rawurlencode($photo)  .  "');\">\n";
			echo negativesprite();
			echo "</a></div>";		
			if (isset($_REQUEST['sharpen']) && $_REQUEST['sharpen'] == 1)
				echo "<div id=\"sharpen\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"Sharpen image\" onclick=\"location.href=('$scriptname?page=$page&amp;sharpen=0$filter_negative$filter_median$filter_edge&amp;photo="  .  rawurlencode($photo)  .  "');\">\n";
			else 
				echo "<div id=\"sharpen\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"Sharpen image\" onclick=\"location.href=('$scriptname?page=$page&amp;sharpen=1$filter_negative$filter_median$filter_edge&amp;photo="  .  rawurlencode($photo)  .  "');\">\n";
			echo sharpensprite();
			echo "</a></div>";			
			if (isset($_REQUEST['noise']) && $_REQUEST['noise'] == 1)
				echo "<div id=\"median\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"Despeckle image\" onclick=\"location.href=('$scriptname?page=$page&amp;noise=0$filter_negative$filter_sharpen$filter_edge&amp;photo="  .  rawurlencode($photo)  .  "');\">\n";
			else 
				echo "<div id=\"median\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"Despeckle image\" onclick=\"location.href=('$scriptname?page=$page&amp;noise=1$filter_negative$filter_sharpen$filter_edge&amp;photo="  .  rawurlencode($photo)  .  "');\">\n";
			echo mediansprite();
			echo "</a></div>";
            if (isset($_REQUEST['edge']) && $_REQUEST['edge'] == 1)
                echo "<div id=\"edge\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"Detect edges\" onclick=\"location.href=('$scriptname?page=$page&amp;edge=0$filter_median$filter_negative$filter_sharpen&amp;photo="  .  rawurlencode($photo)  .  "');\">\n";
            else
                echo "<div id=\"edge\"><a onmouseover=\"this.style.cursor='pointer';\" title=\"Detect edges\" onclick=\"location.href=('$scriptname?page=$page&amp;edge=1$filter_median$filter_negative$filter_sharpen&amp;photo="  .  rawurlencode($photo)  .  "');\">\n";
            echo edgesprite();
            echo "</a></div>";
		}
		// Javascript for loading image ... please wait
		echo "<script type=\"text/javascript\">\n";
		echo "/*<![CDATA[*/\n";
        echo "function hide_message() {\n";
        echo "  var e = document.getElementById('loading');\n";
        echo "  e.style.display = 'none';\n";
        echo "}\n";
		echo " /*//]]>*/\n";
		echo "</script>\n";
	} else {
		echo "<p>" . $message . "</p>\n";
	}
}

// End of page
echo "<div class=\"bottomleft\">" .  bottomleftsprite() . "</div>\n";
echo "<div class=\"bottomright\">" .  bottomrightsprite() . "</div>\n";
echo "</div>\n";
echo "</body></html>\n";

// Functions

function photoalbums($path) {

	global $homedir, $subalbums;
	if ($dir = opendir($path)) {
		while ($dirname = readdir($dir)) {
			if (substr($dirname,0,1) != '.' && is_dir($path . $dirname) && $dirname != 'thumbs') {
				$_SESSION['menulite'][] = array(str_repeat('.', substr_count($path . $dirname, '/', strlen($homedir))-1) . str_replace('.', '', $dirname), substr($path, strlen($homedir) + 1) . $dirname);
				photoalbums($path . $dirname . '/');
				$subalbums = true;
			}
		}
	}  

}

function get_rfc2397() {

	if (isset($_SERVER['HTTP_USER_AGENT'])) {
		$agent = strtolower($_SERVER['HTTP_USER_AGENT']);
		$pattern = '#(?<browser>msie|opera)[/ ]+(?<version>[0-9]+(?:\.[0-9]+)?)#';
		if (!preg_match_all($pattern, $agent, $matches))
			return true;
		$i = count($matches['browser'])-1;
		if ($matches['browser'][$i] == 'msie' && $matches['version'][$i] < 8) {
			return false;
		} else if ($matches['browser'][$i] == 'opera' && $matches['version'][$i] < 7.2) {
			return false;
		} else {
			return true;
		}
	} else {
		return true;
	}
	
}

// Sprites

function backsprite() {

if (!$_SESSION['RFC2397']) return '<';
return '<img src="data:image/gif;base64,R0lGODdhEgANAIAAAGRmZPz+/CwAAAAAEgANAAACJowPqQHs95BrTcKJTb00b451l9QlI1RmZ1p9
aGiBaUyqmmxrilkWADs=" alt="B" title="Browse backward" style="border :0px;width :18px;height :13px;" />';

}

function forwardsprite() {

if (!$_SESSION['RFC2397']) return '>';
return '<img src="data:image/gif;base64,R0lGODdhEgANAIAAAGRmZPz+/CwAAAAAEgANAAACJkSMoBrteKKTL8JJrcYUXm5oHyhmoGdO6Kg2
K9eVWOjKVestDFYAADs=" alt="F" title="Browse forward" style="border :0px;width :18px;height :13px;" />';

}

function slideshowsprite() {

if (!$_SESSION['RFC2397']) return 'S';
return '<img src="data:image/gif;base64,R0lGODdhEwARAIAAAGRmZPz+/CwAAAAAEwARAAACMoSPmRHA3p5ssE5LlVas+98Z4OiJJGmaY+pg
x5WVECXPqhxiZ9WeZbYJumARWnF4FAYLADs=" alt="C" title="Start Slideshow - click image to stop slideshow" style="border :0px;width :19px;height :17px;padding-right : 5px;" />';

}

function negativesprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhEwARAIgAAPv9+2RmZCwAAAAAEwARAAACMIyPmcDtzwycTlJqL5QqgP55oFeF4UI24oo+
64l8rjnOnAIfpralvOr77YSRjhFRAAA7" alt="" title="Negative" style="border :0px;width :19px;height :17px;" />';

}

function sharpensprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhEwARAIgAAPz+/GRmZCwAAAAAEwARAAACK4yPmcDtzwycTs5A7TsXbwRpkfJViqid4Gie
5re8sMiGdB1mHtXxugoMFAAAOw==" alt="" title="Sharpen" style="border :0px;width :19px;height :17px;" />';

}

function mediansprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhEwARAIgAAPz+/GRmZCwAAAAAEwARAAACLYyPmcDtzwycTrZwqaUA9+hB4bN5o3hyVxpl
K6l2Jjdu8du66P2BfMVSKYbDAgA7" alt="" title="Remove noise" style="border :0px;width :19px;height :17px;" />';

}

function edgesprite() {
    
    if (!$_SESSION['RFC2397']) return '';
    return '<img src="data:image/gif;base64,R0lGODdhEwARAIACAPv9+2RmZCwAAAAAEwARAAACKYyPmcDtzwycTlJqL7Sqx/B1yKeFZHmc
    WgpkF+tiHIjO5UbfTXyL/lEAADs=" alt="" title="Edge" style="border :0px;width :19px;height :17px;" />';
    
}

function subcategorysprite() {

if (!$_SESSION['RFC2397']) return '- ';
return '<img src="data:image/gif;base64,R0lGODdhCgAIAIAAAJyanPz+/CwAAAAACgAIAAACD4yPqQFrfeBDQNZ7V3WwAAA7" alt="C" title="Subcategory" style="border :0px;width :10px;height :8px;padding-right : 5px;" />';

}

function rowminsprite() {

if (!$_SESSION['RFC2397']) return 'R-';
return '<img src="data:image/gif;base64,R0lGODdhFQAVAIAAAGRmZPz+/CwAAAAAFQAVAAACRISPqRDtD58JiSJ7LHWMtc5p3jaCnxiW2zlV
7jVFMtTCdtamOmuSO9kLroCYGs42S35Gykis6WRyLlGo7GmdZmmLrqIAADs=" alt="-" title="Show one row with thumbnails less" style="border :0px;width :21px;height :21px;" />';

}

function rowplussprite() {

if (!$_SESSION['RFC2397']) return 'R+';
return '<img src="data:image/gif;base64,R0lGODdhFQAVAIAAAGRmZPz+/CwAAAAAFQAVAAACR4SPqRDtD58JiSJ7LHWMtc5p3jaCnxiW2zlV
7jVFMtTCdtamOmuSO9kLroCYGs42S35GESbNKUnGnpkmNDSbNqVX5XIBThQAADs=" alt="-" title="Show one row with thumbnails more" style="border :0px;width :21px;height :21px;padding-right : 2px;" />';

}

function columnminsprite() {

if (!$_SESSION['RFC2397']) return 'C-';
return '<img src="data:image/gif;base64,R0lGODdhFQAVAIAAAGRmZPz+/CwAAAAAFQAVAAACRYSPqRDtD58JiaJoqWOsdTh93IaFpFhyVxVN
2LuphzW3o6fhdq6hlYlD7X6XHQwWWhVBtx5peHoyec2PRJasTY+vhXdRAAA7" alt="-" title="Show one column with thumbnails less" style="border :0px;width :21px;height :21px;padding-left : 2px;" />';

}

function columnplussprite() {

if (!$_SESSION['RFC2397']) return 'C+';
return '<img src="data:image/gif;base64,R0lGODdhFQAVAIAAAGRmZPz+/CwAAAAAFQAVAAACRoSPqRDtD58JiaJoqWOsdTh93IaFpFhyVxVN
2LuphzV7sWajtjfm59rT6HCZCovogr1CwBooCE0hp63oUCJjOrFK2OK7KAAAOw==" alt="-" title="Show one column with thumbnails more" style="border :0px;width :21px;height :21px;" />';

}

function topleftsprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhDgAOAOMAAMze7Ozy/Nzq9PT6/Nzm9NTi9Pz6/Mzi7Oz2/OTu9Pz+/AAAAAAAAAAAAAAA
AAAAACwAAAAADgAOAAAELxDISUkw6hSwN0lKGFKSgIljdwwoSrGtqAFB7AKgLQKE7uY+BSAoAgZr
RMUpyYwAADs=" alt="" title="" style="border :0px;width :13px;height :13px;" />';

}

function toprightsprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhDgAOAOMAAMze7Ozy/Nzq9PT6/Nzm9NTi9Pz6/Mzi7Oz2/OTu9Pz+/AAAAAAAAAAAAAAA
AAAAACwAAAAADgAOAAAELVCZQIC9WGkdSgFfuG2GgFnjOBwhkKrX8Y4dOI+me2/VvgU6nyLoSwg5
x+QmAgA7" alt="" title="" style="border :0px;width :14px;height :14px;" />';

}

function bottomleftsprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhDgAOAOMAAMze7Ozy/Nzq9PT6/Nzm9NTi9Pz6/Mzi7Oz2/OTu9Pz+/AAAAAAAAAAAAAAA
AAAAACwAAAAADgAOAAAELVDJSau94dqkK+gUkIEKcJBKAXAg4I4aoAJD586wd7uJYc0yF4E1MQF3
iYAvAgA7" alt="" title="" style="border :0px;width :14px;height :14px;" />';

}

function bottomrightsprite() {

if (!$_SESSION['RFC2397']) return '';
return '<img src="data:image/gif;base64,R0lGODdhDgAOAOMAAMze7Ozy/Nzq9PT6/Nzm9NTi9PT2/Pz6/Mzi7Oz2/OTu9Pz+/AAAAAAAAAAA
AAAAACwAAAAADgAOAAAELHDJSau151qjK+lUAUoBMB6ICSqA2JWAehlxIVdlGl9s6+O2mFBlIARt
yFYEADs=" alt="" title="" style="border :0px;width :14px;height :14px;" />';

}

?>
